@@ -121,7 +121,7 @@ class Filter:
                 if source in get_all_sources():
                     raise FilterSourceExistsError(f'the source "{source}" is already the source of another filter')
                 else:
-                    self.source = source
+                    self.source = source if is_url(source) else os.path.realpath(source)
                     self.update(verbosity=False, subscribing_operation=True)
                     print(f' [{Fore.YELLOW}|{Style.RESET_ALL}] Marking filter as subscribed in database', end='\r')
                     with sqlite3.connect(Path.DATABASE) as conn:
